@@ -16,7 +16,7 @@
 __author__ = "Anton Panasenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.19"
+__version__ = "1.0.20"
 __email__ = "apanasenko@qubell.com"
 
 import unittest
@@ -289,14 +289,10 @@ class SandBox(object):
 
     def clean(self, timeout=3):
         log.info("cleaning sandbox...")
-        for instanceData in self.sandbox['instances']:
-            instance = Instance(context=self.platform.context, id=instanceData["id"])
-            instance.destroy()
-            if not instance.destroyed(timeout):
-                log.error(
-                    "Instance was not destroyed properly {0}: {1}".format(instanceData["id"], instanceData["name"])
-                )
-        log.info("sandbox cleaned")
+        for app in self.sandbox['applications']:
+            application = self.organization.get_application(app["id"])
+            application.clean(timeout)
+            application.delete()
 
     def __check_environment_name(self, name):
         import re
